# TestPlanLink


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bug_link** | [**LinkModel**](LinkModel.md) |  | [optional] 
**work_item_global_id** | **int, none_type** |  | [optional] 
**work_item_name** | **str, none_type** |  | [optional] 
**configuration_name** | **str, none_type** |  | [optional] 
**created_by_id** | **str, none_type** |  | [optional] 
**comment** | **str, none_type** |  | [optional] 
**info** | [**ExternalLinkModel**](ExternalLinkModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


